@@ -132,7 +132,7 @@ class hr_analytic_timesheet(osv.osv):
                             _('There is no expense account define ' \
                                     'for this product: "%s" (id:%d)') % \
                                     (r.product_id.name, r.product_id.id,))
-                amount = unit_amount * r.product_id.uom_id._compute_price(cr, uid,
+                amount = unit_amount * self.pool.get('product.uom')._compute_price(cr, uid,
                         r.product_id.uom_id.id, r.product_id.standard_price, False)
                 res ['value']['amount']= - round(amount, 2)
                 res ['value']['general_account_id']= a
