@@ -27,6 +27,7 @@ from tools.config import config
 from tools.translate import _
 import netsvc
 import re
+from tools.safe_eval import safe_eval as eval
 
 class actions(osv.osv):
     _name = 'ir.actions.actions'
@@ -529,7 +530,7 @@ class actions_server(osv.osv):
                         'uid': uid,
                         'object':obj
                         }
-                    exec action.code in localdict
+                    eval(action.code, localdict, 'exec')
                     if 'action' in localdict:
                         return localdict['action']
                 else:
