@@ -27,7 +27,7 @@ from report import report_sxw
 class pos_lines(report_sxw.rml_parse):
 
     def __init__(self, cr, uid, name, context):
-        super(pos_lines, self).__init__(cr, uid, name, context)
+        super(pos_lines, self).__init__(cr, uid, name, context=context)
         self.total = 0.0
         self.localcontext.update({
                 'time': time,
