@@ -28,6 +28,7 @@
 #
 ##############################################################################
 
+__author__ = 'Gaetan de Menten, <ged@tiny.be>'
 __version__ = '0.1.0'
 
 import psycopg
@@ -74,45 +75,61 @@ password = hasattr(options, 'db_password') and "password=%s" % options.db_passwo
 db = psycopg.connect('%s %s %s %s %s' % (host, port, name, user, password), serialize=0)
 cr = db.cursor()
 
-# ------------------------------ #
-# drop not null on ir_attachment #
-# ------------------------------ #
+# ------------------------- #
+# change some columns types #
+# ------------------------- #
 
-cr.execute('ALTER TABLE ir_attachment \
-        ALTER COLUMN res_model DROP NOT NULL, \
-        ALTER COLUMN res_id DROP NOT NULL')
+def change_column(cr, table, column, new_type, copy):
+    commands = [
+        "ALTER TABLE %s RENAME COLUMN %s TO temp_column" % (table, column),
+        "ALTER TABLE %s ADD COLUMN %s %s" % (table, column, new_type),
+        "ALTER TABLE %s DROP COLUMN temp_column" % table
+    ]
+    if copy:
+        commands.insert(
+            2, 
+            "UPDATE %s SET %s=temp_column::%s" % (table, column, new_type))
+
+    for command in commands:
+        cr.execute(command)
+
+change_column(cr, 'crm_case', 'date_closed', 'timestamp', True)
 cr.commit()
 
-# ---------------------------------- #
-# change case date_deadline rounding #
-# ---------------------------------- #
+# -------------------- #
+# add module if needed #
+# -------------------- #
 
-cr.execute("""SELECT
-c.relname,a.attname,a.attlen,a.atttypmod,a.attnotnull,a.atthasdef,t.typname,CASE
-WHEN a.attlen=-1 THEN a.atttypmod-4 ELSE a.attlen END as size FROM pg_class
-c,pg_attribute a,pg_type t WHERE c.relname='crm_case' AND
-a.attname='date_deadline' AND c.oid=a.attrelid AND a.atttypid=t.oid""")
+cr.execute("SELECT name FROM ir_module_module")
+if not cr.rowcount:
+    for module in ('base', 'marketing', 'subscription', 'account', 'base_partner_relation', 'audittrail', 'account_followup', 'product', 'hr', 'l10n_simple', 'crm', 'stock', 'hr_timesheet', 'purchase', 'report_purchase', 'mrp', 'sale', 'report_sale', 'delivery', 'project', 'sale_crm', 'hr_timesheet_project', 'scrum', 'report_project'):
+        cr.execute("INSERT INTO ir_module_module (name, state) VALUES ('%s', 'installed')" % module)
+    cr.commit()
 
-res = cr.dictfetchall()
-if res[0]['typname'] != 'timestamp':
-    for line in (
-        "ALTER TABLE crm_case RENAME date_deadline TO date_deadline_bak",
-        "ALTER TABLE crm_case ADD date_deadline timestamp",
-        "UPDATE crm_case SET date_deadline = date_deadline_bak",
-        "ALTER TABLE crm_case DROP date_deadline_bak",
-        ):
-        cr.execute(line)
+# --------------- #
+# remove old menu #
+# --------------- #
+
+while True:
+    cr.execute("select id from ir_ui_menu where id not in (select parent_id from ir_ui_menu where parent_id is not null) and id not in (select res_id from ir_model_data where model='ir.ui.menu')")
+    if not cr.rowcount:
+        break
+    cr.execute("delete from ir_ui_menu where id not in (select parent_id from ir_ui_menu where parent_id is not null) and id not in (select res_id from ir_model_data where model='ir.ui.menu')")
 cr.commit()
 
-cr.execute('drop view report_task_user_pipeline_open');
+# ----------------------------------------------------- #
+# add some fields (which cannot be added automatically) #
+# ----------------------------------------------------- #
+
+for line in (
+        "ALTER TABLE ir_module_module ADD demo BOOLEAN",
+        "ALTER TABLE ir_module_module SET demo DEFAULT False",
+        "DELETE FROM ir_values WHERE VALUE LIKE '%,False'",
+        """UPDATE ir_ui_view set arch='<?xml version="1.0"?><tree string="Menu" toolbar="1"><field icon="icon" name="name"/></tree>' where name='ir.ui.menu.tree' and type='tree' and field_parent='child_id'""",
+    ):
+    cr.execute(line)
+
 cr.commit()
-
-cr.execute('alter table ir_model_fields add state varchar(26)')
-cr.execute('alter table ir_model_fields add select_level varchar(3)')
-cr.execute('alter table ir_act_wizard add primary key(id)')
-cr.commit()
-
-
 cr.close()
 
 # vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
